https://github.com/DavidSpickett created 
https://github.com/llvm/llvm-project/pull/219139

We've had many reports of timeouts in pre and post-commit.

https://github.com/llvm/llvm-project/issues/137660

>From e64a15d792ae8c8c516ee7016ab2c5e4f48975d7 Mon Sep 17 00:00:00 2001
From: David Spickett <[email protected]>
Date: Thu, 27 Aug 2026 08:09:24 +0000
Subject: [PATCH] [lldb][test] Disable TestDAP_attach.py on AArch64 Linux

We've had many reports of timeouts in pre and post-commit.

https://github.com/llvm/llvm-project/issues/137660
---
 lldb/test/API/tools/lldb-dap/attach/TestDAP_attach.py | 8 +++++---
 1 file changed, 5 insertions(+), 3 deletions(-)

diff --git a/lldb/test/API/tools/lldb-dap/attach/TestDAP_attach.py 
b/lldb/test/API/tools/lldb-dap/attach/TestDAP_attach.py
index bd00ea0d39e21..59c9b80bedbfd 100644
--- a/lldb/test/API/tools/lldb-dap/attach/TestDAP_attach.py
+++ b/lldb/test/API/tools/lldb-dap/attach/TestDAP_attach.py
@@ -16,9 +16,11 @@
 )
 
 
-# Often fails on Arm Linux, but not specifically because it's Arm, something in
-# process scheduling can cause a massive (minutes) delay during this test.
-@skipIf(oslist=["linux"], archs=["arm$"])
+# Often fails on Arm/AArch64 Linux, but not specifically because of the,
+# architecture, something in process scheduling can cause a massive (minutes)
+# delay during this test.
+# https://github.com/llvm/llvm-project/issues/137660
+@skipIf(oslist=["linux"], archs=["arm$", "aarch64"])
 @requireNotWasm("no attach support")
 class TestDAP_attach(DAPTestCaseBase):
     SHARED_BUILD_TESTCASE = False

_______________________________________________
lldb-commits mailing list
[email protected]
https://lists.llvm.org/cgi-bin/mailman/listinfo/lldb-commits

Reply via email to